package com.mortals.xhx.feign.device;

import com.alibaba.fastjson.JSON;
import com.mortals.xhx.common.code.ApiRespCodeEnum;
import com.mortals.xhx.feign.IFeign;
import com.mortals.xhx.feign.device.pdu.DevicePdu;
import com.mortals.xhx.feign.rsp.ApiResp;
import lombok.extern.slf4j.Slf4j;
import org.springframework.cloud.openfeign.FallbackFactory;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;

@FeignClient(name = "device-manager", path = "/m", fallbackFactory = DeviceFeignFallbackFactory.class)
public interface IApiDeviceFeign extends IFeign {

    /**
     * 根据条件查询站点列表
     * @param query
     * @return
     */
    @PostMapping(value = "/device/list")
    String getDeviceByQuery(@RequestBody DevicePdu query);
}

@Slf4j
@Component
class DeviceFeignFallbackFactory implements FallbackFactory<IApiDeviceFeign> {

    @Override
    public IApiDeviceFeign create(Throwable cause) {
        return new IApiDeviceFeign(){

            @Override
            public String getDeviceByQuery(DevicePdu query) {
                ApiResp<String> failResp = new ApiResp<>();
                failResp.setCode(ApiRespCodeEnum.FAILED.getValue());
                failResp.setMsg("暂时无法获取设备列表，请稍后再试!");
                return JSON.toJSONString(failResp);
            }
        };
    }
}
