package com.mortals.xhx.module.certificate.web;

import com.mortals.framework.annotation.UnAuth;
import com.mortals.framework.common.Rest;
import com.mortals.framework.model.Context;
import com.mortals.framework.model.PageInfo;
import com.mortals.framework.model.Result;
import com.mortals.framework.web.BaseCRUDJsonBodyMappingController;
import com.mortals.xhx.annotation.DataPermission;
import com.mortals.xhx.base.system.param.service.ParamService;
import com.mortals.xhx.module.certificate.model.CertificateIndustryEntity;
import com.mortals.xhx.module.certificate.service.CertificateIndustryService;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.stream.Collector;
import java.util.stream.Collectors;

/**
*
* 行业目录
*
* @author zxfei
* @date 2022-10-14
*/
@RestController
@RequestMapping("certificate/industry")
public class CertificateIndustryController extends BaseCRUDJsonBodyMappingController<CertificateIndustryService,CertificateIndustryEntity,Long> {

    @Autowired
    private ParamService paramService;

    public CertificateIndustryController(){
        super.setModuleDesc( "行业目录");
    }

    @Override
    protected void init(Map<String, Object> model, Context context) {
        super.init(model, context);
    }

    @Override
    @DataPermission
    public Rest<Object> list(CertificateIndustryEntity query) {
        return super.list(query);
    }

    @PostMapping({"treeList"})
    @UnAuth
    public Rest<Object> treeList(@RequestBody CertificateIndustryEntity query) {
        Rest<Object> ret = new Rest();
        Map<String, Object> model = new HashMap();
        Context context = this.getContext();
        String busiDesc = "查询" + this.getModuleDesc();
        int code;
        try {
            List<CertificateIndustryEntity> result = this.getService().find(query, context);
            if(CollectionUtils.isNotEmpty(result)){
                List<CertificateIndustryEntity> collect = result.stream().filter(t -> t.getParentId() == -1).map(
                        m -> {
                            m.setChildIndustry(getChildren(m, result));
                            return m;
                        }
                ).collect(Collectors.toList());
                model.put("data", collect);
            }else {
                model.put("data", result);
            }
            code = this.doListAfter(query, (Map)model, context);
            model.put("message_info", busiDesc + "成功");
            this.recordSysLog(this.request, busiDesc + " 【成功】");
        } catch (Exception var9) {
            code = -1;
            this.doException(this.request, busiDesc, model, var9);
        }

        this.init(model, context);
        ret.setCode(code);
        ret.setData(model);
        ret.setDict(model.get("dict"));
        ret.setMsg(model.get("message_info") == null ? "" : model.remove("message_info").toString());
        return ret;
    }

    private static List<CertificateIndustryEntity> getChildren(CertificateIndustryEntity root, List<CertificateIndustryEntity> all) {
        List<CertificateIndustryEntity> children = all.stream().filter(t -> {
            return Objects.equals(t.getParentId(), root.getId());
        }).map(
                m -> {
                    m.setChildIndustry(getChildren(m, all));
                    return m;
                }
        ).collect(Collectors.toList());
        return children;
    }

}